# AIRPrediction
(Framework) AIR Quality Forecast Model leveraging Time Series Models to enable timely preventive measures to reduce harmful impact on U.S. citizens.

## Dataset to Train the Time Series Model AIR.Prototype_ver.1
Include this csv file in the package: 
https://www.kaggle.com/sogun3/uspollution
pollution_us_2000_2016.csv(382.37 MB)

## Package Name for PIP Installation
pip install AIRPrediction

## Command to Run Sample App
python3 sampleapp.py

## Repository Link
https://github.com/Data-for-Good-by-UF/AIR

## Sample Application (Demo.ver Not connected to API)
The following files belong to the Sample Application:
  sampleapp.py  (Demo)
